@@ -1,8 +1,8 @@
-"""exaSPIM pipeline utilites
+"""exaSPIM pipeline utilites top level namespace definition
 """
 from .imagej_macros import ImagejMacros
 from .imagej_wrapper import main
 
 __all__ = ["ImagejMacros", "main"]
 
-__version__ = "0.1.4"
+__version__ = "0.1.5"
